/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED BY BPFTOOL! */
#ifndef __LOCAL_STORAGE_SKEL_H__
#define __LOCAL_STORAGE_SKEL_H__

#include <errno.h>
#include <stdlib.h>
#include <bpf/libbpf.h>

struct local_storage {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *inode_storage_map;
		struct bpf_map *sk_storage_map;
		struct bpf_map *sk_storage_map2;
		struct bpf_map *task_storage_map;
		struct bpf_map *bss;
		struct bpf_map *data;
	} maps;
	struct {
		struct bpf_program *unlink_hook;
		struct bpf_program *inode_rename;
		struct bpf_program *socket_bind;
		struct bpf_program *socket_post_create;
		struct bpf_program *exec;
	} progs;
	struct {
		struct bpf_link *unlink_hook;
		struct bpf_link *inode_rename;
		struct bpf_link *socket_bind;
		struct bpf_link *socket_post_create;
		struct bpf_link *exec;
	} links;
	struct local_storage__bss {
		int monitored_pid;
	} *bss;
	struct local_storage__data {
		int inode_storage_result;
		int sk_storage_result;
	} *data;

#ifdef __cplusplus
	static inline struct local_storage *open(const struct bpf_object_open_opts *opts = nullptr);
	static inline struct local_storage *open_and_load();
	static inline int load(struct local_storage *skel);
	static inline int attach(struct local_storage *skel);
	static inline void detach(struct local_storage *skel);
	static inline void destroy(struct local_storage *skel);
	static inline const void *elf_bytes(size_t *sz);
#endif /* __cplusplus */
};

static void
local_storage__destroy(struct local_storage *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
local_storage__create_skeleton(struct local_storage *obj);

static inline struct local_storage *
local_storage__open_opts(const struct bpf_object_open_opts *opts)
{
	struct local_storage *obj;
	int err;

	obj = (struct local_storage *)calloc(1, sizeof(*obj));
	if (!obj) {
		errno = ENOMEM;
		return NULL;
	}

	err = local_storage__create_skeleton(obj);
	if (err)
		goto err_out;

	err = bpf_object__open_skeleton(obj->skeleton, opts);
	if (err)
		goto err_out;

	return obj;
err_out:
	local_storage__destroy(obj);
	errno = -err;
	return NULL;
}

static inline struct local_storage *
local_storage__open(void)
{
	return local_storage__open_opts(NULL);
}

static inline int
local_storage__load(struct local_storage *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct local_storage *
local_storage__open_and_load(void)
{
	struct local_storage *obj;
	int err;

	obj = local_storage__open();
	if (!obj)
		return NULL;
	err = local_storage__load(obj);
	if (err) {
		local_storage__destroy(obj);
		errno = -err;
		return NULL;
	}
	return obj;
}

static inline int
local_storage__attach(struct local_storage *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
local_storage__detach(struct local_storage *obj)
{
	bpf_object__detach_skeleton(obj->skeleton);
}

static inline const void *local_storage__elf_bytes(size_t *sz);

static inline int
local_storage__create_skeleton(struct local_storage *obj)
{
	struct bpf_object_skeleton *s;
	int err;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)	{
		err = -ENOMEM;
		goto err;
	}

	s->sz = sizeof(*s);
	s->name = "local_storage";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 6;
	s->map_skel_sz = sizeof(*s->maps);
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt, s->map_skel_sz);
	if (!s->maps) {
		err = -ENOMEM;
		goto err;
	}

	s->maps[0].name = "inode_storage_map";
	s->maps[0].map = &obj->maps.inode_storage_map;

	s->maps[1].name = "sk_storage_map";
	s->maps[1].map = &obj->maps.sk_storage_map;

	s->maps[2].name = "sk_storage_map2";
	s->maps[2].map = &obj->maps.sk_storage_map2;

	s->maps[3].name = "task_storage_map";
	s->maps[3].map = &obj->maps.task_storage_map;

	s->maps[4].name = "local_st.bss";
	s->maps[4].map = &obj->maps.bss;
	s->maps[4].mmaped = (void **)&obj->bss;

	s->maps[5].name = "local_st.data";
	s->maps[5].map = &obj->maps.data;
	s->maps[5].mmaped = (void **)&obj->data;

	/* programs */
	s->prog_cnt = 5;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs) {
		err = -ENOMEM;
		goto err;
	}

	s->progs[0].name = "unlink_hook";
	s->progs[0].prog = &obj->progs.unlink_hook;
	s->progs[0].link = &obj->links.unlink_hook;

	s->progs[1].name = "inode_rename";
	s->progs[1].prog = &obj->progs.inode_rename;
	s->progs[1].link = &obj->links.inode_rename;

	s->progs[2].name = "socket_bind";
	s->progs[2].prog = &obj->progs.socket_bind;
	s->progs[2].link = &obj->links.socket_bind;

	s->progs[3].name = "socket_post_create";
	s->progs[3].prog = &obj->progs.socket_post_create;
	s->progs[3].link = &obj->links.socket_post_create;

	s->progs[4].name = "exec";
	s->progs[4].prog = &obj->progs.exec;
	s->progs[4].link = &obj->links.exec;

	s->data = (void *)local_storage__elf_bytes(&s->data_sz);

	obj->skeleton = s;
	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return err;
}

static inline const void *local_storage__elf_bytes(size_t *sz)
{
	*sz = 13640;
	return (const void *)"\
\x7f\x45\x4c\x46\x02\x02\x01\0\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\0\0\x01\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x30\x88\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x13\0\
\x01\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x6c\x73\x6d\
\x2f\x69\x6e\x6f\x64\x65\x5f\x75\x6e\x6c\x69\x6e\x6b\0\x6c\x73\x6d\x2e\x73\x2f\
\x69\x6e\x6f\x64\x65\x5f\x72\x65\x6e\x61\x6d\x65\0\x6c\x73\x6d\x2e\x73\x2f\x73\
\x6f\x63\x6b\x65\x74\x5f\x62\x69\x6e\x64\0\x6c\x73\x6d\x2e\x73\x2f\x73\x6f\x63\
\x6b\x65\x74\x5f\x70\x6f\x73\x74\x5f\x63\x72\x65\x61\x74\x65\0\x6c\x73\x6d\x2e\
\x73\x2f\x62\x70\x72\x6d\x5f\x63\x6f\x6d\x6d\x69\x74\x74\x65\x64\x5f\x63\x72\
\x65\x64\x73\0\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x62\x73\x73\0\x2e\x64\x61\x74\
\x61\0\x2e\x6d\x61\x70\x73\0\x6c\x6f\x63\x61\x6c\x5f\x73\x74\x6f\x72\x61\x67\
\x65\x2e\x63\0\x4c\x42\x42\x30\x5f\x34\0\x4c\x42\x42\x30\x5f\x33\0\x4c\x42\x42\
\x31\x5f\x35\0\x4c\x42\x42\x31\x5f\x33\0\x4c\x42\x42\x32\x5f\x38\0\x4c\x42\x42\
\x32\x5f\x34\0\x4c\x42\x42\x33\x5f\x33\0\x4c\x42\x42\x34\x5f\x35\0\x4c\x42\x42\
\x34\x5f\x33\0\x75\x6e\x6c\x69\x6e\x6b\x5f\x68\x6f\x6f\x6b\0\x6d\x6f\x6e\x69\
\x74\x6f\x72\x65\x64\x5f\x70\x69\x64\0\x74\x61\x73\x6b\x5f\x73\x74\x6f\x72\x61\
\x67\x65\x5f\x6d\x61\x70\0\x69\x6e\x6f\x64\x65\x5f\x72\x65\x6e\x61\x6d\x65\0\
\x69\x6e\x6f\x64\x65\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x6d\x61\x70\0\x69\x6e\
\x6f\x64\x65\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x72\x65\x73\x75\x6c\x74\0\x73\
\x6f\x63\x6b\x65\x74\x5f\x62\x69\x6e\x64\0\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\
\x65\x5f\x6d\x61\x70\0\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x72\x65\x73\
\x75\x6c\x74\0\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x6d\x61\x70\x32\0\
\x73\x6f\x63\x6b\x65\x74\x5f\x70\x6f\x73\x74\x5f\x63\x72\x65\x61\x74\x65\0\x65\
\x78\x65\x63\0\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x72\x65\x6c\x6c\x73\x6d\
\x2f\x69\x6e\x6f\x64\x65\x5f\x75\x6e\x6c\x69\x6e\x6b\0\x2e\x72\x65\x6c\x6c\x73\
\x6d\x2e\x73\x2f\x69\x6e\x6f\x64\x65\x5f\x72\x65\x6e\x61\x6d\x65\0\x2e\x72\x65\
\x6c\x6c\x73\x6d\x2e\x73\x2f\x73\x6f\x63\x6b\x65\x74\x5f\x62\x69\x6e\x64\0\x2e\
\x72\x65\x6c\x6c\x73\x6d\x2e\x73\x2f\x73\x6f\x63\x6b\x65\x74\x5f\x70\x6f\x73\
\x74\x5f\x63\x72\x65\x61\x74\x65\0\x2e\x72\x65\x6c\x6c\x73\x6d\x2e\x73\x2f\x62\
\x70\x72\x6d\x5f\x63\x6f\x6d\x6d\x69\x74\x74\x65\x64\x5f\x63\x72\x65\x64\x73\0\
\x2e\x42\x54\x46\0\x2e\x42\x54\x46\x2e\x65\x78\x74\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x94\x04\0\xff\xf1\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x03\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xa4\0\0\0\
\x03\0\0\0\0\0\0\0\xa8\0\0\0\0\0\0\0\0\0\0\0\xab\0\0\0\x03\0\0\0\0\0\0\0\xa0\0\
\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb2\0\
\0\0\x04\0\0\0\0\0\0\0\xf8\0\0\0\0\0\0\0\0\0\0\0\xb9\0\0\0\x04\0\0\0\0\0\0\0\
\xb0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x05\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\xc0\0\0\0\x05\0\0\0\0\0\0\x01\x48\0\0\0\0\0\0\0\0\0\0\0\xc7\0\0\0\x05\0\0\0\0\
\0\0\0\xa0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\xce\0\0\0\x06\0\0\0\0\0\0\0\x80\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\x07\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xd5\0\0\0\x07\0\0\0\0\0\0\0\xe0\0\0\0\0\0\0\
\0\0\0\0\0\xdc\0\0\0\x07\0\0\0\0\0\0\0\x90\0\0\0\0\0\0\0\0\0\0\0\xe3\x12\0\0\
\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb8\0\0\0\xef\x11\0\0\x09\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x04\0\0\0\xfd\x11\0\0\x0b\0\0\0\0\0\0\0\x60\0\0\0\0\0\0\0\x20\0\0\
\x01\x0e\x12\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x08\0\0\x01\x1b\x11\0\0\
\x0b\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x20\0\0\x01\x2d\x11\0\0\x0a\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x04\0\0\x01\x42\x12\0\0\x05\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x58\
\0\0\x01\x4e\x11\0\0\x0b\0\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\x20\0\0\x01\x5d\x11\0\
\0\x0a\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x04\0\0\x01\x6f\x11\0\0\x0b\0\0\0\0\0\0\
\0\x40\0\0\0\0\0\0\0\x20\0\0\x01\x7f\x12\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x90\0\0\x01\x92\x12\0\0\x07\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xe8\0\0\x01\x97\x11\
\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\xb4\x60\0\0\0\0\0\0\x79\x71\0\x08\0\
\0\0\0\x85\0\0\0\0\0\0\x0e\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x61\x11\0\0\0\0\
\0\0\x77\0\0\0\0\0\0\x20\x5e\x10\0\x0d\0\0\0\0\x85\0\0\0\0\0\0\x9e\x18\x10\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\xbf\x20\0\0\0\0\0\0\xb7\x30\0\0\0\0\0\0\xb7\x40\0\0\0\
\0\0\0\x85\0\0\0\0\0\0\x9c\x15\0\0\x04\0\0\0\0\xb4\x60\0\0\xff\xff\xff\xff\x79\
\x17\0\x30\0\0\0\0\x79\x20\0\0\0\0\0\0\x1d\x21\0\x01\0\0\0\0\xb4\x60\0\0\0\0\0\
\0\xbc\x06\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x79\x61\0\x08\0\0\0\0\x79\x71\0\x18\0\
\0\0\0\x85\0\0\0\0\0\0\x0e\x79\x27\0\x30\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\xb7\x30\0\0\0\0\0\0\xb7\x40\0\0\0\0\0\x01\x85\0\0\0\0\0\0\x91\x79\x26\0\
\x30\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x30\0\0\0\0\0\0\xb7\x40\0\
\0\0\0\0\0\x85\0\0\0\0\0\0\x91\x15\0\0\x0f\0\0\0\0\x61\x10\0\x08\0\0\0\0\x16\
\x10\0\x04\xde\xad\xbe\xef\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb4\x20\0\0\xff\
\xff\xff\xff\x63\x12\0\0\0\0\0\0\x79\x26\0\x30\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x85\0\0\0\0\0\0\x92\x56\0\0\x04\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\xb4\x20\0\0\0\0\0\0\x63\x12\0\0\0\0\0\0\xb4\0\0\0\0\0\0\0\x95\0\0\0\
\0\0\0\0\x79\x61\0\0\0\0\0\0\x85\0\0\0\0\0\0\x0e\x18\x10\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x61\x11\0\0\0\0\0\0\x77\0\0\0\0\0\0\x20\x5e\x10\0\x22\0\0\0\0\x79\x26\0\
\x18\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x30\0\0\0\0\0\0\xb7\x40\0\
\0\0\0\0\x01\x85\0\0\0\0\0\0\x6b\x15\0\0\x1b\0\0\0\0\x61\x10\0\x08\0\0\0\0\x16\
\x10\0\x04\xde\xad\xbe\xef\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb4\x20\0\0\xff\
\xff\xff\xff\x63\x12\0\0\0\0\0\0\x79\x26\0\x18\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\xb7\x30\0\0\0\0\0\0\xb7\x40\0\0\0\0\0\x01\x85\0\0\0\0\0\0\x6b\x15\
\0\0\x0e\0\0\0\0\x79\x26\0\x18\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x85\
\0\0\0\0\0\0\x6c\x56\0\0\x09\0\0\0\0\x79\x26\0\x18\0\0\0\0\x18\x10\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x85\0\0\0\0\0\0\x6c\x56\0\0\x04\0\0\0\0\x18\x10\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\xb4\x20\0\0\0\0\0\0\x63\x12\0\0\0\0\0\0\xb4\0\0\0\0\0\0\0\x95\0\
\0\0\0\0\0\0\x79\x61\0\0\0\0\0\0\x85\0\0\0\0\0\0\x0e\x18\x10\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x61\x11\0\0\0\0\0\0\x77\0\0\0\0\0\0\x20\x5e\x10\0\x09\0\0\0\0\x79\
\x26\0\x18\0\0\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x30\0\0\0\0\0\0\xb7\
\x40\0\0\0\0\0\x01\x85\0\0\0\0\0\0\x6b\x15\0\0\x02\0\0\0\0\xb4\x10\0\0\xde\xad\
\xbe\xef\x63\x01\0\x08\0\0\0\0\xb4\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x79\x61\0\0\
\0\0\0\0\x85\0\0\0\0\0\0\x0e\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x61\x11\0\0\0\
\0\0\0\x77\0\0\0\0\0\0\x20\x5e\x10\0\x15\0\0\0\0\x85\0\0\0\0\0\0\x9e\x18\x10\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\xbf\x20\0\0\0\0\0\0\xb7\x30\0\0\0\0\0\0\xb7\x40\0\0\
\0\0\0\x01\x85\0\0\0\0\0\0\x9c\x15\0\0\x03\0\0\0\0\x79\x16\0\x40\0\0\0\0\x79\
\x11\0\x20\0\0\0\0\x7b\x01\0\0\0\0\0\0\x79\x16\0\x40\0\0\0\0\x79\x21\0\x20\0\0\
\0\0\x18\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x30\0\0\0\0\0\0\xb7\x40\0\0\0\0\0\
\x01\x85\0\0\0\0\0\0\x91\x15\0\0\x02\0\0\0\0\xb4\x10\0\0\xde\xad\xbe\xef\x63\
\x01\0\x08\0\0\0\0\x95\0\0\0\0\0\0\0\x47\x50\x4c\0\xff\xff\xff\xff\xff\xff\xff\
\xff\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x18\0\0\0\x11\0\0\0\x01\0\0\0\
\0\0\0\0\x48\0\0\0\x12\0\0\0\x01\0\0\0\0\0\0\0\x20\0\0\0\x14\0\0\0\x01\0\0\0\0\
\0\0\0\x50\0\0\0\x14\0\0\0\x01\0\0\0\0\0\0\0\x90\0\0\0\x15\0\0\0\x01\0\0\0\0\0\
\0\0\xb8\0\0\0\x14\0\0\0\x01\0\0\0\0\0\0\0\xd8\0\0\0\x15\0\0\0\x01\0\0\0\0\0\0\
\0\x10\0\0\0\x11\0\0\0\x01\0\0\0\0\0\0\0\x40\0\0\0\x17\0\0\0\x01\0\0\0\0\0\0\0\
\x80\0\0\0\x18\0\0\0\x01\0\0\0\0\0\0\0\xa8\0\0\0\x19\0\0\0\x01\0\0\0\0\0\0\0\
\xe0\0\0\0\x17\0\0\0\x01\0\0\0\0\0\0\x01\x08\0\0\0\x19\0\0\0\x01\0\0\0\0\0\0\
\x01\x28\0\0\0\x18\0\0\0\x01\0\0\0\0\0\0\0\x10\0\0\0\x11\0\0\0\x01\0\0\0\0\0\0\
\0\x40\0\0\0\x17\0\0\0\x01\0\0\0\0\0\0\0\x10\0\0\0\x11\0\0\0\x01\0\0\0\0\0\0\0\
\x40\0\0\0\x12\0\0\0\x01\0\0\0\0\0\0\0\xa0\0\0\0\x14\0\0\0\x01\xeb\x9f\x01\0\0\
\0\0\x18\0\0\0\0\0\0\x10\x0c\0\0\x10\x0c\0\0\x0e\x76\0\0\0\0\x02\0\0\0\0\0\0\
\x03\0\0\0\x01\x01\0\0\0\0\0\0\x04\x01\0\0\x20\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\
\x02\0\0\0\x04\0\0\0\x1c\0\0\0\x05\x01\0\0\0\0\0\0\x04\0\0\0\x20\0\0\0\0\x02\0\
\0\0\0\0\0\x06\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\x04\0\0\0\x01\0\0\0\0\
\x02\0\0\0\0\0\0\x02\0\0\0\0\x02\0\0\0\0\0\0\x09\0\0\0\x19\x04\0\0\x02\0\0\0\
\x10\0\0\0\x27\0\0\0\x0a\0\0\0\0\0\0\0\x32\0\0\0\x0b\0\0\0\x40\0\0\0\0\x02\0\0\
\0\0\0\0\x92\0\0\0\x38\x08\0\0\0\0\0\0\x0c\0\0\0\x3e\x01\0\0\0\0\0\0\x04\0\0\0\
\x20\0\0\0\0\x04\0\0\x04\0\0\0\x20\0\0\0\x4b\0\0\0\x01\0\0\0\0\0\0\0\x50\0\0\0\
\x05\0\0\0\x40\0\0\0\x5a\0\0\0\x07\0\0\0\x80\0\0\0\x32\0\0\0\x08\0\0\0\xc0\0\0\
\0\x5e\x0e\0\0\0\0\0\0\x0d\0\0\0\x01\0\0\0\0\x02\0\0\0\0\0\0\x10\0\0\0\0\x03\0\
\0\0\0\0\0\0\0\0\0\x02\0\0\0\x04\0\0\0\x18\0\0\0\0\x02\0\0\0\0\0\0\x12\0\0\0\0\
\x03\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\x04\0\0\x02\x01\0\0\0\0\x04\0\0\x04\0\0\0\
\x20\0\0\0\x4b\0\0\0\x0f\0\0\0\0\0\0\0\x50\0\0\0\x11\0\0\0\x40\0\0\0\x5a\0\0\0\
\x07\0\0\0\x80\0\0\0\x32\0\0\0\x08\0\0\0\xc0\0\0\0\x70\x0e\0\0\0\0\0\0\x13\0\0\
\0\x01\0\0\0\x7f\x0e\0\0\0\0\0\0\x13\0\0\0\x01\0\0\0\0\x02\0\0\0\0\0\0\x17\0\0\
\0\0\x03\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\x04\0\0\0\x1d\0\0\0\0\x04\0\0\x04\0\0\0\
\x20\0\0\0\x4b\0\0\0\x16\0\0\0\0\0\0\0\x50\0\0\0\x05\0\0\0\x40\0\0\0\x5a\0\0\0\
\x07\0\0\0\x80\0\0\0\x32\0\0\0\x08\0\0\0\xc0\0\0\0\x8f\x0e\0\0\0\0\0\0\x18\0\0\
\0\x01\0\0\0\0\x02\0\0\0\0\0\0\x1b\0\0\0\xa0\x01\0\0\0\0\0\0\x08\0\0\0\x40\0\0\
\0\0\x0d\0\0\x01\0\0\0\x02\0\0\0\xb3\0\0\0\x1a\0\0\0\xb7\x0c\0\0\x01\0\0\0\x1c\
\0\0\0\xc3\x04\0\0\x10\0\0\0\xc0\0\0\0\xca\0\0\0\x0c\0\0\0\0\0\0\0\xd2\0\0\0\
\x1f\0\0\0\x20\0\0\0\xd8\0\0\0\x23\0\0\0\x40\0\0\0\xdf\0\0\0\x26\0\0\0\xc0\0\0\
\0\xe8\0\0\0\x27\0\0\x01\0\0\0\0\xef\0\0\0\x0a\0\0\x01\x80\0\0\0\xf7\0\0\0\x30\
\0\0\x01\xc0\0\0\0\xff\0\0\0\x31\0\0\x02\xc0\0\0\x01\x09\0\0\0\x3a\0\0\x03\0\0\
\0\x01\x0e\0\0\0\x3c\0\0\x03\x40\0\0\x01\x13\0\0\0\x3d\0\0\x03\x80\0\0\x01\x1a\
\0\0\0\x3e\0\0\x03\xc0\0\0\0\0\0\0\0\x3f\0\0\x04\0\0\0\x01\x23\0\0\0\x40\0\0\
\x04\x80\0\0\x01\x2b\0\0\0\x40\0\0\x05\0\0\0\x01\x35\0\0\0\x44\0\0\x05\x80\0\0\
\x01\x39\x08\0\0\0\0\0\0\x20\0\0\x01\x4d\x04\0\0\x01\0\0\0\x04\0\0\x01\x5f\0\0\
\0\x21\0\0\0\0\0\0\x01\x68\x08\0\0\0\0\0\0\x22\0\0\x01\x5f\x04\0\0\x01\0\0\0\
\x04\0\0\x01\x73\0\0\0\x0c\0\0\0\0\0\0\x01\x7c\x04\0\0\x02\0\0\0\x10\0\0\x01\
\x8a\0\0\0\x24\0\0\0\0\0\0\x01\x8f\0\0\0\x25\0\0\0\x40\0\0\0\0\x02\0\0\0\0\0\0\
\x23\0\0\0\0\x02\0\0\0\0\0\0\x24\0\0\0\0\x02\0\0\0\0\0\0\x1e\0\0\x01\x95\x04\0\
\0\x02\0\0\0\x10\0\0\0\0\0\0\0\x28\0\0\0\0\0\0\x01\x9a\0\0\0\x2d\0\0\0\x40\0\0\
\0\0\x05\0\0\x02\0\0\0\x08\0\0\0\0\0\0\0\x29\0\0\0\0\0\0\x01\x9f\0\0\0\x2b\0\0\
\0\0\0\0\0\0\x04\0\0\x02\0\0\0\x08\0\0\x01\xa8\0\0\0\x2a\0\0\0\0\0\0\x01\xac\0\
\0\0\x2a\0\0\0\x20\0\0\x01\xb1\x08\0\0\0\0\0\0\x0b\0\0\x01\xb5\x08\0\0\0\0\0\0\
\x2c\0\0\x01\xb9\x08\0\0\0\0\0\0\x1b\0\0\0\0\x02\0\0\0\0\0\0\x2e\0\0\0\0\x0a\0\
\0\0\0\0\0\x2f\0\0\x01\xbf\x01\0\0\0\0\0\0\x01\0\0\0\x08\0\0\0\0\x03\0\0\0\0\0\
\0\0\0\0\0\x2f\0\0\0\x04\0\0\0\x20\0\0\x01\xcd\x04\0\0\x01\0\0\0\x08\0\0\0\0\0\
\0\0\x32\0\0\0\0\0\0\0\0\x05\0\0\x02\0\0\0\x08\0\0\x01\xd5\0\0\0\x2c\0\0\0\0\0\
\0\0\0\0\0\0\x33\0\0\0\0\0\0\0\0\x04\0\0\x02\0\0\0\x08\0\0\x01\xe0\0\0\0\x34\0\
\0\0\0\0\0\x01\xe5\0\0\0\x02\0\0\0\x20\0\0\x01\xeb\x08\0\0\0\0\0\0\x35\0\0\x01\
\xf6\x04\0\0\x01\0\0\0\x04\0\0\0\0\0\0\0\x36\0\0\0\0\0\0\0\0\x05\0\0\x01\0\0\0\
\x04\0\0\x01\xff\0\0\0\x37\0\0\0\0\0\0\x02\x05\x04\0\0\x01\0\0\0\x04\0\0\x02\
\x12\0\0\0\x38\0\0\0\0\0\0\x02\x1b\x08\0\0\0\0\0\0\x39\0\0\0\0\x04\0\0\x01\0\0\
\0\x04\0\0\x01\xe0\0\0\0\x02\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\x3b\0\0\0\0\x0a\0\
\0\0\0\0\0\x93\0\0\0\0\x02\0\0\0\0\0\0\x95\0\0\x02\x2b\x01\0\0\0\0\0\0\x08\0\0\
\0\x40\0\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\x05\0\0\x02\0\0\0\x10\0\0\x02\x39\0\0\
\0\x40\0\0\0\0\0\0\x02\x3f\0\0\0\x42\0\0\0\0\0\0\x02\x46\x04\0\0\x02\0\0\0\x10\
\0\0\x01\x8a\0\0\0\x41\0\0\0\0\0\0\x02\x50\0\0\0\x41\0\0\0\x40\0\0\0\0\x02\0\0\
\0\0\0\0\x40\0\0\0\0\x02\0\0\0\0\0\0\x43\0\0\x02\x55\x08\0\0\0\0\0\0\x57\0\0\0\
\0\x05\0\0\x03\0\0\0\x10\0\0\x02\x67\0\0\0\x45\0\0\0\0\0\0\x02\x6f\0\0\0\x23\0\
\0\0\0\0\0\x02\x80\0\0\0\x48\0\0\0\0\0\0\x02\x86\x04\0\0\x02\0\0\0\x10\0\0\x01\
\x8a\0\0\0\x46\0\0\0\0\0\0\x01\x8f\0\0\0\x47\0\0\0\x40\0\0\0\0\x02\0\0\0\0\0\0\
\x45\0\0\0\0\x02\0\0\0\0\0\0\x46\0\0\x02\x91\x04\0\0\x02\0\0\0\x10\0\0\x01\x8a\
\0\0\0\x49\0\0\0\0\0\0\x02\x9f\0\0\0\x4a\0\0\0\x40\0\0\0\0\x02\0\0\0\0\0\0\x48\
\0\0\0\0\x02\0\0\0\0\0\0\x4b\0\0\0\0\x0d\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x49\0\0\
\x02\xa4\x0c\0\0\x01\0\0\0\x1c\0\0\x02\xb1\x0c\0\0\x01\0\0\0\x1c\0\0\x02\xbd\
\x04\0\0\x07\0\0\x02\0\0\0\x02\xc4\0\0\0\x4f\0\0\0\0\0\0\0\x4b\0\0\0\x51\0\0\0\
\x20\0\0\x02\xca\0\0\0\x3d\0\0\0\x40\0\0\x02\xd0\0\0\0\x52\0\0\0\x80\0\0\x02\
\xd5\0\0\0\x53\0\0\0\xc0\0\0\x02\xd8\0\0\0\x54\0\0\x01\0\0\0\x02\xdc\0\0\0\x56\
\0\0\x08\0\0\0\x02\xdf\x08\0\0\0\0\0\0\x50\0\0\0\0\x06\0\0\x05\0\0\0\x04\0\0\
\x02\xec\0\0\0\0\0\0\x02\xf4\0\0\0\x01\0\0\x03\x03\0\0\0\x02\0\0\x03\x11\0\0\0\
\x03\0\0\x03\x1e\0\0\0\x04\0\0\x03\x2f\x01\0\0\0\0\0\0\x02\x01\0\0\x10\0\0\0\0\
\x02\0\0\0\0\0\0\x66\0\0\0\0\x02\0\0\0\0\0\0\x9e\0\0\0\0\x02\0\0\0\0\0\0\x55\0\
\0\0\0\x0a\0\0\0\0\0\0\x9d\0\0\x03\x35\x04\0\0\x04\0\0\x01\0\0\0\x03\x3f\0\0\0\
\x43\0\0\0\0\0\0\x03\x44\0\0\0\x58\0\0\0\xc0\0\0\x02\xca\0\0\0\x3d\0\0\x01\0\0\
\0\x03\x50\0\0\0\x48\0\0\x01\x40\0\0\x03\x54\x04\0\0\x02\0\0\0\x18\0\0\x01\xe0\
\0\0\0\x34\0\0\0\0\0\0\x03\x64\0\0\0\x40\0\0\0\x40\0\0\0\0\x02\0\0\0\0\0\0\x9c\
\0\0\x03\x69\x0c\0\0\x01\0\0\0\x1c\0\0\0\0\x0d\0\0\x01\0\0\0\0\0\0\0\xb3\0\0\0\
\x1a\0\0\x03\x7c\x0c\0\0\x01\0\0\0\x5a\0\0\x03\x81\x84\0\0\x1a\0\0\x01\xa0\0\0\
\x03\x8e\0\0\0\x5d\0\0\0\0\0\0\x03\x92\0\0\0\x3d\0\0\0\x40\0\0\x03\x9c\0\0\0\
\x5e\0\0\0\x80\0\0\x03\x9f\0\0\0\x3d\0\0\0\xc0\0\0\x03\xa1\0\0\0\x3d\0\0\x01\0\
\0\0\x03\xa8\0\0\0\x0c\x01\0\x01\x40\0\0\x03\xb4\0\0\0\x0c\x01\0\x01\x41\0\0\
\x03\xc1\0\0\0\x0c\x01\0\x01\x42\0\0\x03\xcc\0\0\0\x0c\x01\0\x01\x43\0\0\x03\
\xdf\0\0\0\x52\0\0\x01\x80\0\0\x03\xea\0\0\0\x52\0\0\x01\xc0\0\0\x02\xd0\0\0\0\
\x52\0\0\x02\0\0\0\x03\xf6\0\0\0\x5f\0\0\x02\x40\0\0\x03\xfb\0\0\0\x02\0\0\x02\
\x80\0\0\x04\x02\0\0\0\x0c\0\0\x02\xa0\0\0\x04\x0c\0\0\0\x02\0\0\x02\xc0\0\0\
\x04\x11\0\0\0\x02\0\0\x02\xe0\0\0\x04\x16\0\0\0\x60\0\0\x03\0\0\0\x04\x1f\0\0\
\0\x60\0\0\x03\x40\0\0\x04\x26\0\0\0\x60\0\0\x03\x80\0\0\x04\x2d\0\0\0\x0c\0\0\
\x03\xc0\0\0\x04\x3a\0\0\0\x02\0\0\x03\xe0\0\0\x04\x41\0\0\0\x3d\0\0\x04\0\0\0\
\x03\x7c\0\0\0\x3d\0\0\x04\x40\0\0\x04\x48\0\0\0\x63\0\0\x04\x80\0\0\x04\x53\0\
\0\0\x65\0\0\x05\0\0\0\0\0\x02\0\0\0\0\0\0\x9a\0\0\0\0\x02\0\0\0\0\0\0\x99\0\0\
\0\0\x02\0\0\0\0\0\0\x98\0\0\0\0\x02\0\0\0\0\0\0\x61\0\0\0\0\x0a\0\0\0\0\0\0\
\x62\0\0\x04\x57\x01\0\0\0\0\0\0\x01\x01\0\0\x08\0\0\x04\x5c\x04\0\0\x02\0\0\0\
\x10\0\0\x04\x63\0\0\0\x64\0\0\0\0\0\0\x04\x6c\0\0\0\x64\0\0\0\x40\0\0\x04\x75\
\x08\0\0\0\0\0\0\x3d\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x62\0\0\0\x04\0\0\x01\0\0\
\0\x02\xd0\x04\0\0\x14\0\0\0\xe8\0\0\x04\x86\0\0\0\x67\0\0\0\0\0\0\x04\x8a\0\0\
\0\x6a\0\0\0\x80\0\0\x04\x91\0\0\0\x0a\0\0\x01\0\0\0\x04\x99\0\0\0\x6c\0\0\x01\
\x40\0\0\x04\x9e\0\0\0\x34\0\0\x01\x80\0\0\x04\xa5\0\0\0\x6e\0\0\x01\xc0\0\0\
\x04\xad\0\0\0\x0c\0\0\x02\0\0\0\x04\xb5\0\0\0\x74\0\0\x02\x20\0\0\x04\xbc\0\0\
\0\x75\0\0\x02\x40\0\0\x04\xc7\0\0\0\x7a\0\0\x03\x40\0\0\x04\xcd\0\0\0\x7c\0\0\
\x03\x80\0\0\x04\xd5\0\0\0\x87\0\0\x04\x80\0\0\x04\xdc\0\0\0\x89\0\0\x04\xc0\0\
\0\x04\xe1\0\0\0\x2b\0\0\x05\xc0\0\0\x04\xeb\0\0\0\x3e\0\0\x06\0\0\0\x04\xf6\0\
\0\0\x3e\0\0\x06\x40\0\0\x05\x03\0\0\0\x8a\0\0\x06\x80\0\0\x05\x08\0\0\0\x8b\0\
\0\x06\xc0\0\0\x05\x12\0\0\0\x8c\0\0\x07\0\0\0\x05\x1b\0\0\0\x8c\0\0\x07\x20\0\
\0\0\0\x05\0\0\x02\0\0\0\x10\0\0\x05\x24\0\0\0\x68\0\0\0\0\0\0\x05\x2d\0\0\0\
\x48\0\0\0\0\0\0\x05\x38\x04\0\0\x01\0\0\0\x08\0\0\x01\x8a\0\0\0\x69\0\0\0\0\0\
\0\0\0\x02\0\0\0\0\0\0\x68\0\0\x05\x43\x04\0\0\x02\0\0\0\x10\0\0\x05\x48\0\0\0\
\x6b\0\0\0\0\0\0\0\xc3\0\0\0\x26\0\0\0\x40\0\0\0\0\x02\0\0\0\0\0\0\x94\0\0\0\0\
\x02\0\0\0\0\0\0\x6d\0\0\0\0\x0a\0\0\0\0\0\0\x96\0\0\x05\x4c\x08\0\0\0\0\0\0\
\x6f\0\0\x05\x5a\x08\0\0\0\0\0\0\x70\0\0\0\0\x04\0\0\x01\0\0\0\x08\0\0\x05\x65\
\0\0\0\x71\0\0\0\0\0\0\x05\x6d\x08\0\0\0\0\0\0\x72\0\0\x05\x71\x08\0\0\0\0\0\0\
\x73\0\0\x05\x77\x01\0\0\0\0\0\0\x08\x01\0\0\x40\0\0\x05\x81\x08\0\0\0\0\0\0\
\x0c\0\0\x05\x89\x04\0\0\x04\0\0\0\x20\0\0\x05\x8f\0\0\0\x6e\0\0\0\0\0\0\x05\
\x95\0\0\0\x76\0\0\0\x40\0\0\x05\x9f\0\0\0\x77\0\0\0\x60\0\0\x05\xa3\0\0\0\x40\
\0\0\0\x80\0\0\x05\xad\x08\0\0\0\0\0\0\x37\0\0\x05\xbc\x04\0\0\x01\0\0\0\x04\0\
\0\x05\xd2\0\0\0\x78\0\0\0\0\0\0\x05\xd7\x08\0\0\0\0\0\0\x79\0\0\0\0\x04\0\0\
\x01\0\0\0\x04\0\0\x05\x65\0\0\0\x02\0\0\0\0\0\0\x05\xe0\x08\0\0\0\0\0\0\x7b\0\
\0\x05\xe7\x08\0\0\0\0\0\0\x73\0\0\x05\xf7\x04\0\0\x06\0\0\0\x20\0\0\x01\xe0\0\
\0\0\x7d\0\0\0\0\0\0\x06\x03\0\0\0\x81\0\0\0\x40\0\0\x06\x07\0\0\0\x82\0\0\0\
\x80\0\0\x06\x10\0\0\0\x83\0\0\0\xa0\0\0\x06\x14\0\0\0\x83\0\0\0\xc0\0\0\x06\
\x19\0\0\0\x02\0\0\0\xe0\0\0\x06\x20\x08\0\0\0\0\0\0\x7e\0\0\0\0\x04\0\0\x01\0\
\0\0\x08\0\0\x02\x12\0\0\0\x7f\0\0\0\0\0\0\x06\x29\x08\0\0\0\0\0\0\x80\0\0\0\0\
\x04\0\0\x02\0\0\0\x08\0\0\x06\x37\0\0\0\x02\0\0\0\0\0\0\x03\x3f\0\0\0\x38\0\0\
\0\x20\0\0\0\0\x02\0\0\0\0\0\0\x9f\0\0\x06\x07\x06\0\0\x05\0\0\0\x04\0\0\x06\
\x3c\0\0\0\0\0\0\x06\x48\0\0\0\x01\0\0\x06\x55\0\0\0\x02\0\0\x06\x62\0\0\0\x03\
\0\0\x06\x6e\0\0\0\x04\0\0\x06\x7a\x08\0\0\0\0\0\0\x84\0\0\0\0\x04\0\0\x01\0\0\
\0\x04\0\0\x06\x81\0\0\0\x85\0\0\0\0\0\0\x06\x85\x08\0\0\0\0\0\0\x86\0\0\x06\
\x8b\x08\0\0\0\0\0\0\x0c\0\0\0\0\x02\0\0\0\0\0\0\x88\0\0\0\0\x0a\0\0\0\0\0\0\
\x98\0\0\x06\x9c\x04\0\0\x06\0\0\0\x20\0\0\x06\xaa\0\0\0\x3d\0\0\0\0\0\0\x06\
\xb0\0\0\0\x0c\0\0\0\x40\0\0\x06\xb5\0\0\0\x0c\0\0\0\x60\0\0\x06\xc0\0\0\0\x0c\
\0\0\0\x80\0\0\x06\xc9\0\0\0\x0c\0\0\0\xa0\0\0\x06\xd3\0\0\0\x7a\0\0\0\xc0\0\0\
\0\0\x02\0\0\0\0\0\0\x9b\0\0\0\0\x02\0\0\0\0\0\0\x97\0\0\x06\xdc\x08\0\0\0\0\0\
\0\x2a\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\x62\0\0\0\x04\0\0\0\x04\0\0\x06\xe5\x0e\
\0\0\0\0\0\0\x8d\0\0\0\x01\0\0\x06\xee\x0e\0\0\0\0\0\0\x02\0\0\0\x01\0\0\x06\
\xfc\x0e\0\0\0\0\0\0\x02\0\0\0\x01\0\0\x07\x11\x0e\0\0\0\0\0\0\x02\0\0\0\x01\0\
\0\x07\x23\x07\0\0\0\0\0\0\0\0\0\x07\x29\x07\0\0\0\0\0\0\0\0\0\x07\x3b\x07\0\0\
\0\0\0\0\0\0\0\x07\x44\x07\0\0\0\0\0\0\0\0\0\x07\x50\x07\0\0\0\0\0\0\0\0\0\x07\
\x60\x07\0\0\0\0\0\0\0\0\0\x03\xf6\x07\0\0\0\0\0\0\0\0\0\x07\x6e\x07\0\0\0\0\0\
\0\0\0\0\x07\x78\x07\0\0\0\0\0\0\0\0\0\x07\x87\x07\0\0\0\0\0\0\0\0\0\x07\x92\
\x07\0\0\0\0\0\0\0\0\0\x07\xa0\x07\0\0\0\0\0\0\0\0\0\x07\xaa\x07\0\0\0\0\0\0\0\
\0\0\x06\x03\x07\0\0\0\0\0\0\0\0\0\x0d\xf3\x0f\0\0\x01\0\0\0\x04\0\0\0\x8e\0\0\
\0\0\0\0\0\x04\0\0\x0d\xfb\x0f\0\0\x01\0\0\0\x04\0\0\0\x8f\0\0\0\0\0\0\0\x04\0\
\0\x0e\0\x0f\0\0\x02\0\0\0\x08\0\0\0\x90\0\0\0\0\0\0\0\x04\0\0\0\x91\0\0\0\x04\
\0\0\0\x04\0\0\x0e\x06\x0f\0\0\x04\0\0\0\x80\0\0\0\x0e\0\0\0\0\0\0\0\x20\0\0\0\
\x14\0\0\0\x20\0\0\0\x20\0\0\0\x15\0\0\0\x40\0\0\0\x20\0\0\0\x19\0\0\0\x60\0\0\
\0\x20\0\x69\x6e\x74\0\x5f\x5f\x41\x52\x52\x41\x59\x5f\x53\x49\x5a\x45\x5f\x54\
\x59\x50\x45\x5f\x5f\0\x6c\x6f\x63\x61\x6c\x5f\x73\x74\x6f\x72\x61\x67\x65\0\
\x65\x78\x65\x63\x5f\x69\x6e\x6f\x64\x65\0\x76\x61\x6c\x75\x65\0\x5f\x5f\x75\
\x33\x32\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x69\x6e\x74\0\x74\x79\x70\x65\0\
\x6d\x61\x70\x5f\x66\x6c\x61\x67\x73\0\x6b\x65\x79\0\x69\x6e\x6f\x64\x65\x5f\
\x73\x74\x6f\x72\x61\x67\x65\x5f\x6d\x61\x70\0\x73\x6b\x5f\x73\x74\x6f\x72\x61\
\x67\x65\x5f\x6d\x61\x70\0\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x6d\x61\
\x70\x32\0\x74\x61\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x6d\x61\x70\0\
\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x6c\x6f\x6e\x67\x20\x6c\x6f\x6e\x67\0\x63\
\x74\x78\0\x75\x6e\x6c\x69\x6e\x6b\x5f\x68\x6f\x6f\x6b\0\x64\x65\x6e\x74\x72\
\x79\0\x64\x5f\x66\x6c\x61\x67\x73\0\x64\x5f\x73\x65\x71\0\x64\x5f\x68\x61\x73\
\x68\0\x64\x5f\x70\x61\x72\x65\x6e\x74\0\x64\x5f\x6e\x61\x6d\x65\0\x64\x5f\x69\
\x6e\x6f\x64\x65\0\x64\x5f\x69\x6e\x61\x6d\x65\0\x64\x5f\x6c\x6f\x63\x6b\x72\
\x65\x66\0\x64\x5f\x6f\x70\0\x64\x5f\x73\x62\0\x64\x5f\x74\x69\x6d\x65\0\x64\
\x5f\x66\x73\x64\x61\x74\x61\0\x64\x5f\x63\x68\x69\x6c\x64\0\x64\x5f\x73\x75\
\x62\x64\x69\x72\x73\0\x64\x5f\x75\0\x73\x65\x71\x63\x6f\x75\x6e\x74\x5f\x73\
\x70\x69\x6e\x6c\x6f\x63\x6b\x5f\x74\0\x73\x65\x71\x63\x6f\x75\x6e\x74\x5f\x73\
\x70\x69\x6e\x6c\x6f\x63\x6b\0\x73\x65\x71\x63\x6f\x75\x6e\x74\0\x73\x65\x71\
\x63\x6f\x75\x6e\x74\x5f\x74\0\x73\x65\x71\x75\x65\x6e\x63\x65\0\x68\x6c\x69\
\x73\x74\x5f\x62\x6c\x5f\x6e\x6f\x64\x65\0\x6e\x65\x78\x74\0\x70\x70\x72\x65\
\x76\0\x71\x73\x74\x72\0\x6e\x61\x6d\x65\0\x68\x61\x73\x68\x5f\x6c\x65\x6e\0\
\x6c\x65\x6e\0\x68\x61\x73\x68\0\x75\x33\x32\0\x75\x36\x34\0\x5f\x5f\x75\x36\
\x34\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x63\x68\x61\x72\0\x6c\x6f\x63\x6b\
\x72\x65\x66\0\x6c\x6f\x63\x6b\x5f\x63\x6f\x75\x6e\x74\0\x6c\x6f\x63\x6b\0\x63\
\x6f\x75\x6e\x74\0\x73\x70\x69\x6e\x6c\x6f\x63\x6b\x5f\x74\0\x73\x70\x69\x6e\
\x6c\x6f\x63\x6b\0\x72\x6c\x6f\x63\x6b\0\x72\x61\x77\x5f\x73\x70\x69\x6e\x6c\
\x6f\x63\x6b\0\x72\x61\x77\x5f\x6c\x6f\x63\x6b\0\x61\x72\x63\x68\x5f\x73\x70\
\x69\x6e\x6c\x6f\x63\x6b\x5f\x74\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x6c\x6f\
\x6e\x67\0\x64\x5f\x6c\x72\x75\0\x64\x5f\x77\x61\x69\x74\0\x6c\x69\x73\x74\x5f\
\x68\x65\x61\x64\0\x70\x72\x65\x76\0\x77\x61\x69\x74\x5f\x71\x75\x65\x75\x65\
\x5f\x68\x65\x61\x64\x5f\x74\0\x64\x5f\x61\x6c\x69\x61\x73\0\x64\x5f\x69\x6e\
\x5f\x6c\x6f\x6f\x6b\x75\x70\x5f\x68\x61\x73\x68\0\x64\x5f\x72\x63\x75\0\x68\
\x6c\x69\x73\x74\x5f\x6e\x6f\x64\x65\0\x63\x61\x6c\x6c\x62\x61\x63\x6b\x5f\x68\
\x65\x61\x64\0\x66\x75\x6e\x63\0\x69\x6e\x6f\x64\x65\x5f\x72\x65\x6e\x61\x6d\
\x65\0\x73\x6f\x63\x6b\x65\x74\x5f\x62\x69\x6e\x64\0\x73\x6f\x63\x6b\x65\x74\0\
\x73\x74\x61\x74\x65\0\x66\x6c\x61\x67\x73\0\x66\x69\x6c\x65\0\x73\x6b\0\x6f\
\x70\x73\0\x77\x71\0\x73\x6f\x63\x6b\x65\x74\x5f\x73\x74\x61\x74\x65\0\x53\x53\
\x5f\x46\x52\x45\x45\0\x53\x53\x5f\x55\x4e\x43\x4f\x4e\x4e\x45\x43\x54\x45\x44\
\0\x53\x53\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4e\x47\0\x53\x53\x5f\x43\x4f\
\x4e\x4e\x45\x43\x54\x45\x44\0\x53\x53\x5f\x44\x49\x53\x43\x4f\x4e\x4e\x45\x43\
\x54\x49\x4e\x47\0\x73\x68\x6f\x72\x74\0\x73\x6f\x63\x6b\x65\x74\x5f\x77\x71\0\
\x77\x61\x69\x74\0\x66\x61\x73\x79\x6e\x63\x5f\x6c\x69\x73\x74\0\x72\x63\x75\0\
\x77\x61\x69\x74\x5f\x71\x75\x65\x75\x65\x5f\x68\x65\x61\x64\0\x68\x65\x61\x64\
\0\x73\x6f\x63\x6b\x65\x74\x5f\x70\x6f\x73\x74\x5f\x63\x72\x65\x61\x74\x65\0\
\x65\x78\x65\x63\0\x6c\x69\x6e\x75\x78\x5f\x62\x69\x6e\x70\x72\x6d\0\x76\x6d\
\x61\0\x76\x6d\x61\x5f\x70\x61\x67\x65\x73\0\x6d\x6d\0\x70\0\x61\x72\x67\x6d\
\x69\x6e\0\x68\x61\x76\x65\x5f\x65\x78\x65\x63\x66\x64\0\x65\x78\x65\x63\x66\
\x64\x5f\x63\x72\x65\x64\x73\0\x73\x65\x63\x75\x72\x65\x65\x78\x65\x63\0\x70\
\x6f\x69\x6e\x74\x5f\x6f\x66\x5f\x6e\x6f\x5f\x72\x65\x74\x75\x72\x6e\0\x65\x78\
\x65\x63\x75\x74\x61\x62\x6c\x65\0\x69\x6e\x74\x65\x72\x70\x72\x65\x74\x65\x72\
\0\x63\x72\x65\x64\0\x75\x6e\x73\x61\x66\x65\0\x70\x65\x72\x5f\x63\x6c\x65\x61\
\x72\0\x61\x72\x67\x63\0\x65\x6e\x76\x63\0\x66\x69\x6c\x65\x6e\x61\x6d\x65\0\
\x69\x6e\x74\x65\x72\x70\0\x66\x64\x70\x61\x74\x68\0\x69\x6e\x74\x65\x72\x70\
\x5f\x66\x6c\x61\x67\x73\0\x65\x78\x65\x63\x66\x64\0\x6c\x6f\x61\x64\x65\x72\0\
\x72\x6c\x69\x6d\x5f\x73\x74\x61\x63\x6b\0\x62\x75\x66\0\x63\x68\x61\x72\0\x72\
\x6c\x69\x6d\x69\x74\0\x72\x6c\x69\x6d\x5f\x63\x75\x72\0\x72\x6c\x69\x6d\x5f\
\x6d\x61\x78\0\x5f\x5f\x6b\x65\x72\x6e\x65\x6c\x5f\x75\x6c\x6f\x6e\x67\x5f\x74\
\0\x66\x5f\x75\0\x66\x5f\x70\x61\x74\x68\0\x66\x5f\x69\x6e\x6f\x64\x65\0\x66\
\x5f\x6f\x70\0\x66\x5f\x6c\x6f\x63\x6b\0\x66\x5f\x63\x6f\x75\x6e\x74\0\x66\x5f\
\x66\x6c\x61\x67\x73\0\x66\x5f\x6d\x6f\x64\x65\0\x66\x5f\x70\x6f\x73\x5f\x6c\
\x6f\x63\x6b\0\x66\x5f\x70\x6f\x73\0\x66\x5f\x6f\x77\x6e\x65\x72\0\x66\x5f\x63\
\x72\x65\x64\0\x66\x5f\x72\x61\0\x66\x5f\x76\x65\x72\x73\x69\x6f\x6e\0\x66\x5f\
\x73\x65\x63\x75\x72\x69\x74\x79\0\x70\x72\x69\x76\x61\x74\x65\x5f\x64\x61\x74\
\x61\0\x66\x5f\x65\x70\0\x66\x5f\x6d\x61\x70\x70\x69\x6e\x67\0\x66\x5f\x77\x62\
\x5f\x65\x72\x72\0\x66\x5f\x73\x62\x5f\x65\x72\x72\0\x66\x75\x5f\x6c\x6c\x69\
\x73\x74\0\x66\x75\x5f\x72\x63\x75\x68\x65\x61\x64\0\x6c\x6c\x69\x73\x74\x5f\
\x6e\x6f\x64\x65\0\x70\x61\x74\x68\0\x6d\x6e\x74\0\x61\x74\x6f\x6d\x69\x63\x5f\
\x6c\x6f\x6e\x67\x5f\x74\0\x61\x74\x6f\x6d\x69\x63\x36\x34\x5f\x74\0\x63\x6f\
\x75\x6e\x74\x65\x72\0\x73\x36\x34\0\x5f\x5f\x73\x36\x34\0\x6c\x6f\x6e\x67\x20\
\x6c\x6f\x6e\x67\0\x66\x6d\x6f\x64\x65\x5f\x74\0\x6d\x75\x74\x65\x78\0\x6f\x77\
\x6e\x65\x72\0\x77\x61\x69\x74\x5f\x6c\x6f\x63\x6b\0\x6f\x73\x71\0\x77\x61\x69\
\x74\x5f\x6c\x69\x73\x74\0\x72\x61\x77\x5f\x73\x70\x69\x6e\x6c\x6f\x63\x6b\x5f\
\x74\0\x6f\x70\x74\x69\x6d\x69\x73\x74\x69\x63\x5f\x73\x70\x69\x6e\x5f\x71\x75\
\x65\x75\x65\0\x74\x61\x69\x6c\0\x61\x74\x6f\x6d\x69\x63\x5f\x74\0\x6c\x6f\x66\
\x66\x5f\x74\0\x5f\x5f\x6b\x65\x72\x6e\x65\x6c\x5f\x6c\x6f\x66\x66\x5f\x74\0\
\x66\x6f\x77\x6e\x5f\x73\x74\x72\x75\x63\x74\0\x70\x69\x64\0\x70\x69\x64\x5f\
\x74\x79\x70\x65\0\x75\x69\x64\0\x65\x75\x69\x64\0\x73\x69\x67\x6e\x75\x6d\0\
\x72\x77\x6c\x6f\x63\x6b\x5f\x74\0\x61\x72\x63\x68\x5f\x72\x77\x6c\x6f\x63\x6b\
\x5f\x74\0\x63\x6e\x74\x73\0\x50\x49\x44\x54\x59\x50\x45\x5f\x50\x49\x44\0\x50\
\x49\x44\x54\x59\x50\x45\x5f\x54\x47\x49\x44\0\x50\x49\x44\x54\x59\x50\x45\x5f\
\x50\x47\x49\x44\0\x50\x49\x44\x54\x59\x50\x45\x5f\x53\x49\x44\0\x50\x49\x44\
\x54\x59\x50\x45\x5f\x4d\x41\x58\0\x6b\x75\x69\x64\x5f\x74\0\x76\x61\x6c\0\x75\
\x69\x64\x5f\x74\0\x5f\x5f\x6b\x65\x72\x6e\x65\x6c\x5f\x75\x69\x64\x33\x32\x5f\
\x74\0\x66\x69\x6c\x65\x5f\x72\x61\x5f\x73\x74\x61\x74\x65\0\x73\x74\x61\x72\
\x74\0\x73\x69\x7a\x65\0\x61\x73\x79\x6e\x63\x5f\x73\x69\x7a\x65\0\x72\x61\x5f\
\x70\x61\x67\x65\x73\0\x6d\x6d\x61\x70\x5f\x6d\x69\x73\x73\0\x70\x72\x65\x76\
\x5f\x70\x6f\x73\0\x65\x72\x72\x73\x65\x71\x5f\x74\0\x5f\x6c\x69\x63\x65\x6e\
\x73\x65\0\x6d\x6f\x6e\x69\x74\x6f\x72\x65\x64\x5f\x70\x69\x64\0\x69\x6e\x6f\
\x64\x65\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x72\x65\x73\x75\x6c\x74\0\x73\x6b\
\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x72\x65\x73\x75\x6c\x74\0\x69\x6e\x6f\x64\
\x65\0\x64\x65\x6e\x74\x72\x79\x5f\x6f\x70\x65\x72\x61\x74\x69\x6f\x6e\x73\0\
\x76\x66\x73\x6d\x6f\x75\x6e\x74\0\x73\x75\x70\x65\x72\x5f\x62\x6c\x6f\x63\x6b\
\0\x66\x69\x6c\x65\x5f\x6f\x70\x65\x72\x61\x74\x69\x6f\x6e\x73\0\x61\x64\x64\
\x72\x65\x73\x73\x5f\x73\x70\x61\x63\x65\0\x6d\x6d\x5f\x73\x74\x72\x75\x63\x74\
\0\x76\x6d\x5f\x61\x72\x65\x61\x5f\x73\x74\x72\x75\x63\x74\0\x68\x6c\x69\x73\
\x74\x5f\x68\x65\x61\x64\0\x66\x61\x73\x79\x6e\x63\x5f\x73\x74\x72\x75\x63\x74\
\0\x70\x72\x6f\x74\x6f\x5f\x6f\x70\x73\0\x73\x6f\x63\x6b\0\x2f\x62\x75\x69\x6c\
\x64\x64\x69\x72\x2f\x62\x75\x69\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\x6b\x65\
\x72\x6e\x65\x6c\x2d\x35\x2e\x31\x34\x2e\x30\x2d\x33\x32\x35\x2e\x65\x6c\x39\
\x2f\x6c\x69\x6e\x75\x78\x2d\x35\x2e\x31\x34\x2e\x30\x2d\x33\x32\x35\x2e\x65\
\x6c\x39\x2e\x73\x33\x39\x30\x78\x2f\x74\x6f\x6f\x6c\x73\x2f\x74\x65\x73\x74\
\x69\x6e\x67\x2f\x73\x65\x6c\x66\x74\x65\x73\x74\x73\x2f\x62\x70\x66\x2f\x70\
\x72\x6f\x67\x73\x2f\x6c\x6f\x63\x61\x6c\x5f\x73\x74\x6f\x72\x61\x67\x65\x2e\
\x63\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x75\x6e\x6c\x69\x6e\
\x6b\x5f\x68\x6f\x6f\x6b\x2c\x20\x73\x74\x72\x75\x63\x74\x20\x69\x6e\x6f\x64\
\x65\x20\x2a\x64\x69\x72\x2c\x20\x73\x74\x72\x75\x63\x74\x20\x64\x65\x6e\x74\
\x72\x79\x20\x2a\x76\x69\x63\x74\x69\x6d\x29\0\x09\x5f\x5f\x75\x33\x32\x20\x70\
\x69\x64\x20\x3d\x20\x62\x70\x66\x5f\x67\x65\x74\x5f\x63\x75\x72\x72\x65\x6e\
\x74\x5f\x70\x69\x64\x5f\x74\x67\x69\x64\x28\x29\x20\x3e\x3e\x20\x33\x32\x3b\0\
\x09\x69\x66\x20\x28\x70\x69\x64\x20\x21\x3d\x20\x6d\x6f\x6e\x69\x74\x6f\x72\
\x65\x64\x5f\x70\x69\x64\x29\0\x09\x09\x09\x09\x20\x20\x20\x20\x20\x20\x20\x62\
\x70\x66\x5f\x67\x65\x74\x5f\x63\x75\x72\x72\x65\x6e\x74\x5f\x74\x61\x73\x6b\
\x5f\x62\x74\x66\x28\x29\x2c\x20\x30\x2c\x20\x30\x29\x3b\0\x09\x73\x74\x6f\x72\
\x61\x67\x65\x20\x3d\x20\x62\x70\x66\x5f\x74\x61\x73\x6b\x5f\x73\x74\x6f\x72\
\x61\x67\x65\x5f\x67\x65\x74\x28\x26\x74\x61\x73\x6b\x5f\x73\x74\x6f\x72\x61\
\x67\x65\x5f\x6d\x61\x70\x2c\0\x09\x69\x66\x20\x28\x73\x74\x6f\x72\x61\x67\x65\
\x29\x20\x7b\0\x09\x09\x69\x73\x5f\x73\x65\x6c\x66\x5f\x75\x6e\x6c\x69\x6e\x6b\
\x20\x3d\x20\x73\x74\x6f\x72\x61\x67\x65\x2d\x3e\x65\x78\x65\x63\x5f\x69\x6e\
\x6f\x64\x65\x20\x3d\x3d\x20\x76\x69\x63\x74\x69\x6d\x2d\x3e\x64\x5f\x69\x6e\
\x6f\x64\x65\x3b\0\x09\x09\x69\x66\x20\x28\x69\x73\x5f\x73\x65\x6c\x66\x5f\x75\
\x6e\x6c\x69\x6e\x6b\x29\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\
\x69\x6e\x6f\x64\x65\x5f\x72\x65\x6e\x61\x6d\x65\x2c\x20\x73\x74\x72\x75\x63\
\x74\x20\x69\x6e\x6f\x64\x65\x20\x2a\x6f\x6c\x64\x5f\x64\x69\x72\x2c\x20\x73\
\x74\x72\x75\x63\x74\x20\x64\x65\x6e\x74\x72\x79\x20\x2a\x6f\x6c\x64\x5f\x64\
\x65\x6e\x74\x72\x79\x2c\0\x09\x62\x70\x66\x5f\x69\x6e\x6f\x64\x65\x5f\x73\x74\
\x6f\x72\x61\x67\x65\x5f\x67\x65\x74\x28\x26\x69\x6e\x6f\x64\x65\x5f\x73\x74\
\x6f\x72\x61\x67\x65\x5f\x6d\x61\x70\x2c\x20\x6e\x65\x77\x5f\x64\x65\x6e\x74\
\x72\x79\x2d\x3e\x64\x5f\x69\x6e\x6f\x64\x65\x2c\x20\x30\x2c\0\x09\x73\x74\x6f\
\x72\x61\x67\x65\x20\x3d\x20\x62\x70\x66\x5f\x69\x6e\x6f\x64\x65\x5f\x73\x74\
\x6f\x72\x61\x67\x65\x5f\x67\x65\x74\x28\x26\x69\x6e\x6f\x64\x65\x5f\x73\x74\
\x6f\x72\x61\x67\x65\x5f\x6d\x61\x70\x2c\x20\x6f\x6c\x64\x5f\x64\x65\x6e\x74\
\x72\x79\x2d\x3e\x64\x5f\x69\x6e\x6f\x64\x65\x2c\0\x09\x69\x66\x20\x28\x21\x73\
\x74\x6f\x72\x61\x67\x65\x29\0\x09\x69\x66\x20\x28\x73\x74\x6f\x72\x61\x67\x65\
\x2d\x3e\x76\x61\x6c\x75\x65\x20\x21\x3d\x20\x44\x55\x4d\x4d\x59\x5f\x53\x54\
\x4f\x52\x41\x47\x45\x5f\x56\x41\x4c\x55\x45\x29\0\x09\x09\x69\x6e\x6f\x64\x65\
\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x72\x65\x73\x75\x6c\x74\x20\x3d\x20\x2d\
\x31\x3b\0\x09\x65\x72\x72\x20\x3d\x20\x62\x70\x66\x5f\x69\x6e\x6f\x64\x65\x5f\
\x73\x74\x6f\x72\x61\x67\x65\x5f\x64\x65\x6c\x65\x74\x65\x28\x26\x69\x6e\x6f\
\x64\x65\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x6d\x61\x70\x2c\x20\x6f\x6c\x64\
\x5f\x64\x65\x6e\x74\x72\x79\x2d\x3e\x64\x5f\x69\x6e\x6f\x64\x65\x29\x3b\0\x09\
\x69\x66\x20\x28\x21\x65\x72\x72\x29\0\x09\x09\x69\x6e\x6f\x64\x65\x5f\x73\x74\
\x6f\x72\x61\x67\x65\x5f\x72\x65\x73\x75\x6c\x74\x20\x3d\x20\x65\x72\x72\x3b\0\
\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x73\x6f\x63\x6b\x65\x74\
\x5f\x62\x69\x6e\x64\x2c\x20\x73\x74\x72\x75\x63\x74\x20\x73\x6f\x63\x6b\x65\
\x74\x20\x2a\x73\x6f\x63\x6b\x2c\x20\x73\x74\x72\x75\x63\x74\x20\x73\x6f\x63\
\x6b\x61\x64\x64\x72\x20\x2a\x61\x64\x64\x72\x65\x73\x73\x2c\0\x09\x73\x74\x6f\
\x72\x61\x67\x65\x20\x3d\x20\x62\x70\x66\x5f\x73\x6b\x5f\x73\x74\x6f\x72\x61\
\x67\x65\x5f\x67\x65\x74\x28\x26\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\
\x6d\x61\x70\x2c\x20\x73\x6f\x63\x6b\x2d\x3e\x73\x6b\x2c\x20\x30\x2c\0\x09\x09\
\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x72\x65\x73\x75\x6c\x74\x20\x3d\
\x20\x2d\x31\x3b\0\x09\x73\x74\x6f\x72\x61\x67\x65\x20\x3d\x20\x62\x70\x66\x5f\
\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x67\x65\x74\x28\x26\x73\x6b\x5f\
\x73\x74\x6f\x72\x61\x67\x65\x5f\x6d\x61\x70\x32\x2c\x20\x73\x6f\x63\x6b\x2d\
\x3e\x73\x6b\x2c\x20\x30\x2c\0\x09\x65\x72\x72\x20\x3d\x20\x62\x70\x66\x5f\x73\
\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x64\x65\x6c\x65\x74\x65\x28\x26\x73\
\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x6d\x61\x70\x2c\x20\x73\x6f\x63\x6b\
\x2d\x3e\x73\x6b\x29\x3b\0\x09\x69\x66\x20\x28\x65\x72\x72\x29\0\x09\x65\x72\
\x72\x20\x3d\x20\x62\x70\x66\x5f\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\
\x64\x65\x6c\x65\x74\x65\x28\x26\x73\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\
\x6d\x61\x70\x32\x2c\x20\x73\x6f\x63\x6b\x2d\x3e\x73\x6b\x29\x3b\0\x09\x09\x73\
\x6b\x5f\x73\x74\x6f\x72\x61\x67\x65\x5f\x72\x65\x73\x75\x6c\x74\x20\x3d\x20\
\x65\x72\x72\x3b\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x73\x6f\
\x63\x6b\x65\x74\x5f\x70\x6f\x73\x74\x5f\x63\x72\x65\x61\x74\x65\x2c\x20\x73\
\x74\x72\x75\x63\x74\x20\x73\x6f\x63\x6b\x65\x74\x20\x2a\x73\x6f\x63\x6b\x2c\
\x20\x69\x6e\x74\x20\x66\x61\x6d\x69\x6c\x79\x2c\x20\x69\x6e\x74\x20\x74\x79\
\x70\x65\x2c\0\x09\x73\x74\x6f\x72\x61\x67\x65\x2d\x3e\x76\x61\x6c\x75\x65\x20\
\x3d\x20\x44\x55\x4d\x4d\x59\x5f\x53\x54\x4f\x52\x41\x47\x45\x5f\x56\x41\x4c\
\x55\x45\x3b\0\x76\x6f\x69\x64\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x65\x78\
\x65\x63\x2c\x20\x73\x74\x72\x75\x63\x74\x20\x6c\x69\x6e\x75\x78\x5f\x62\x69\
\x6e\x70\x72\x6d\x20\x2a\x62\x70\x72\x6d\x29\0\x09\x09\x09\x09\x20\x20\x20\x20\
\x20\x20\x20\x62\x70\x66\x5f\x67\x65\x74\x5f\x63\x75\x72\x72\x65\x6e\x74\x5f\
\x74\x61\x73\x6b\x5f\x62\x74\x66\x28\x29\x2c\x20\x30\x2c\0\x09\x69\x66\x20\x28\
\x73\x74\x6f\x72\x61\x67\x65\x29\0\x09\x09\x73\x74\x6f\x72\x61\x67\x65\x2d\x3e\
\x65\x78\x65\x63\x5f\x69\x6e\x6f\x64\x65\x20\x3d\x20\x62\x70\x72\x6d\x2d\x3e\
\x66\x69\x6c\x65\x2d\x3e\x66\x5f\x69\x6e\x6f\x64\x65\x3b\0\x09\x73\x74\x6f\x72\
\x61\x67\x65\x20\x3d\x20\x62\x70\x66\x5f\x69\x6e\x6f\x64\x65\x5f\x73\x74\x6f\
\x72\x61\x67\x65\x5f\x67\x65\x74\x28\x26\x69\x6e\x6f\x64\x65\x5f\x73\x74\x6f\
\x72\x61\x67\x65\x5f\x6d\x61\x70\x2c\x20\x62\x70\x72\x6d\x2d\x3e\x66\x69\x6c\
\x65\x2d\x3e\x66\x5f\x69\x6e\x6f\x64\x65\x2c\0\x30\x3a\x35\0\x30\x3a\x34\0\x30\
\x3a\x31\x31\0\x30\x3a\x32\0\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x62\x73\x73\0\
\x2e\x64\x61\x74\x61\0\x2e\x6d\x61\x70\x73\0\x6c\x73\x6d\x2f\x69\x6e\x6f\x64\
\x65\x5f\x75\x6e\x6c\x69\x6e\x6b\0\x6c\x73\x6d\x2e\x73\x2f\x69\x6e\x6f\x64\x65\
\x5f\x72\x65\x6e\x61\x6d\x65\0\x6c\x73\x6d\x2e\x73\x2f\x73\x6f\x63\x6b\x65\x74\
\x5f\x62\x69\x6e\x64\0\x6c\x73\x6d\x2e\x73\x2f\x73\x6f\x63\x6b\x65\x74\x5f\x70\
\x6f\x73\x74\x5f\x63\x72\x65\x61\x74\x65\0\x6c\x73\x6d\x2e\x73\x2f\x62\x70\x72\
\x6d\x5f\x63\x6f\x6d\x6d\x69\x74\x74\x65\x64\x5f\x63\x72\x65\x64\x73\0\0\0\0\0\
\0\0\xeb\x9f\x01\0\0\0\0\x20\0\0\0\0\0\0\0\x54\0\0\0\x54\0\0\x04\xfc\0\0\x05\
\x50\0\0\0\xfc\0\0\0\x08\0\0\x0e\x0c\0\0\0\x01\0\0\0\0\0\0\0\x1d\0\0\x0e\x1d\0\
\0\0\x01\0\0\0\0\0\0\0\x4c\0\0\x0e\x30\0\0\0\x01\0\0\0\0\0\0\0\x4d\0\0\x0e\x42\
\0\0\0\x01\0\0\0\0\0\0\0\x59\0\0\x0e\x5b\0\0\0\x01\0\0\0\0\0\0\0\x5b\0\0\0\x10\
\0\0\x0e\x0c\0\0\0\x0d\0\0\0\0\0\0\x07\xaf\0\0\x08\x28\0\0\xd8\0\0\0\0\x08\0\0\
\x07\xaf\0\0\x08\x28\0\0\xd8\x05\0\0\0\x10\0\0\x07\xaf\0\0\x08\x6c\0\0\xe0\x0e\
\0\0\0\x18\0\0\x07\xaf\0\0\x08\x9b\0\0\xf0\x0d\0\0\0\x30\0\0\x07\xaf\0\0\x08\
\x6c\0\0\xe0\x29\0\0\0\x38\0\0\x07\xaf\0\0\x08\x9b\0\0\xf0\x06\0\0\0\x40\0\0\
\x07\xaf\0\0\x08\xb6\0\x01\0\x0c\0\0\0\x48\0\0\x07\xaf\0\0\x08\xe4\0\0\xfc\x0c\
\0\0\0\x78\0\0\x07\xaf\0\0\x09\x17\0\x01\x04\x06\0\0\0\x88\0\0\x07\xaf\0\0\x09\
\x27\0\x01\x0c\x33\0\0\0\x90\0\0\x07\xaf\0\0\x09\x27\0\x01\x0c\x1d\0\0\0\x98\0\
\0\x07\xaf\0\0\x09\x62\0\x01\x10\x07\0\0\0\xa8\0\0\x07\xaf\0\0\x08\x28\0\0\xd8\
\x05\0\0\x0e\x1d\0\0\0\x0f\0\0\0\0\0\0\x07\xaf\0\0\x09\x78\0\x01\x30\x05\0\0\0\
\x10\0\0\x07\xaf\0\0\x08\x6c\0\x01\x40\x0e\0\0\0\x18\0\0\x07\xaf\0\0\x09\xc5\0\
\x01\x60\x38\0\0\0\x20\0\0\x07\xaf\0\0\x09\xc5\0\x01\x60\x02\0\0\0\x48\0\0\x07\
\xaf\0\0\x0a\x08\0\x01\x6c\x42\0\0\0\x50\0\0\x07\xaf\0\0\x0a\x08\0\x01\x6c\x0c\
\0\0\0\x78\0\0\x07\xaf\0\0\x0a\x52\0\x01\x74\x06\0\0\0\x80\0\0\x07\xaf\0\0\x0a\
\x61\0\x01\x80\x0f\0\0\0\x88\0\0\x07\xaf\0\0\x0a\x61\0\x01\x80\x06\0\0\0\x90\0\
\0\x07\xaf\0\0\x0a\x8d\0\x01\x84\x18\0\0\0\xb0\0\0\x07\xaf\0\0\x0a\xaa\0\x01\
\x8c\x41\0\0\0\xb8\0\0\x07\xaf\0\0\x0a\xaa\0\x01\x8c\x08\0\0\0\xd0\0\0\x07\xaf\
\0\0\x0a\xf4\0\x01\x90\x06\0\0\0\xd8\0\0\x07\xaf\0\0\x0a\xff\0\x01\x94\x18\0\0\
\0\xf8\0\0\x07\xaf\0\0\x09\x78\0\x01\x30\x05\0\0\x0e\x30\0\0\0\x16\0\0\0\0\0\0\
\x07\xaf\0\0\x0b\x1d\0\x01\xac\x05\0\0\0\x08\0\0\x07\xaf\0\0\x08\x6c\0\x01\xb8\
\x0e\0\0\0\x10\0\0\x07\xaf\0\0\x08\x9b\0\x01\xc8\x0d\0\0\0\x28\0\0\x07\xaf\0\0\
\x08\x6c\0\x01\xb8\x29\0\0\0\x30\0\0\x07\xaf\0\0\x08\x9b\0\x01\xc8\x06\0\0\0\
\x38\0\0\x07\xaf\0\0\x0b\x66\0\x01\xd4\x36\0\0\0\x40\0\0\x07\xaf\0\0\x0b\x66\0\
\x01\xd4\x0c\0\0\0\x68\0\0\x07\xaf\0\0\x0a\x52\0\x01\xdc\x06\0\0\0\x70\0\0\x07\
\xaf\0\0\x0a\x61\0\x01\xe8\x0f\0\0\0\x78\0\0\x07\xaf\0\0\x0a\x61\0\x01\xe8\x06\
\0\0\0\x80\0\0\x07\xaf\0\0\x0b\xa2\0\x01\xec\x15\0\0\0\xa0\0\0\x07\xaf\0\0\x0b\
\xbc\0\x02\0\x37\0\0\0\xa8\0\0\x07\xaf\0\0\x0b\xbc\0\x02\0\x0c\0\0\0\xd0\0\0\
\x07\xaf\0\0\x0a\x52\0\x02\x08\x06\0\0\0\xd8\0\0\x07\xaf\0\0\x0b\xf9\0\x02\x14\
\x35\0\0\0\xe0\0\0\x07\xaf\0\0\x0b\xf9\0\x02\x14\x08\0\0\0\xf8\0\0\x07\xaf\0\0\
\x0c\x32\0\x02\x18\x06\0\0\x01\0\0\0\x07\xaf\0\0\x0c\x3c\0\x02\x24\x36\0\0\x01\
\x08\0\0\x07\xaf\0\0\x0c\x3c\0\x02\x24\x08\0\0\x01\x20\0\0\x07\xaf\0\0\x0a\xf4\
\0\x02\x28\x06\0\0\x01\x28\0\0\x07\xaf\0\0\x0c\x76\0\x02\x2c\x15\0\0\x01\x48\0\
\0\x07\xaf\0\0\x0b\x1d\0\x01\xac\x05\0\0\x0e\x42\0\0\0\x0a\0\0\0\0\0\0\x07\xaf\
\0\0\x0c\x91\0\x02\x44\x05\0\0\0\x08\0\0\x07\xaf\0\0\x08\x6c\0\x02\x50\x0e\0\0\
\0\x10\0\0\x07\xaf\0\0\x08\x9b\0\x02\x5c\x0d\0\0\0\x28\0\0\x07\xaf\0\0\x08\x6c\
\0\x02\x50\x29\0\0\0\x30\0\0\x07\xaf\0\0\x08\x9b\0\x02\x5c\x06\0\0\0\x38\0\0\
\x07\xaf\0\0\x0b\x66\0\x02\x68\x36\0\0\0\x40\0\0\x07\xaf\0\0\x0b\x66\0\x02\x68\
\x0c\0\0\0\x68\0\0\x07\xaf\0\0\x0a\x52\0\x02\x70\x06\0\0\0\x78\0\0\x07\xaf\0\0\
\x0c\xdd\0\x02\x7c\x11\0\0\0\x80\0\0\x07\xaf\0\0\x0c\x91\0\x02\x44\x05\0\0\x0e\
\x5b\0\0\0\x11\0\0\0\0\0\0\x07\xaf\0\0\x0d\x04\0\x02\xa0\x06\0\0\0\x08\0\0\x07\
\xaf\0\0\x08\x6c\0\x02\xa8\x0e\0\0\0\x10\0\0\x07\xaf\0\0\x08\x9b\0\x02\xb4\x0d\
\0\0\0\x28\0\0\x07\xaf\0\0\x08\x6c\0\x02\xa8\x29\0\0\0\x30\0\0\x07\xaf\0\0\x08\
\x9b\0\x02\xb4\x06\0\0\0\x38\0\0\x07\xaf\0\0\x0d\x33\0\x02\xc4\x0c\0\0\0\x40\0\
\0\x07\xaf\0\0\x08\xe4\0\x02\xc0\x0c\0\0\0\x70\0\0\x07\xaf\0\0\x0d\x5d\0\x02\
\xcc\x06\0\0\0\x78\0\0\x07\xaf\0\0\x0d\x6b\0\x02\xd0\x1f\0\0\0\x80\0\0\x07\xaf\
\0\0\x0d\x6b\0\x02\xd0\x25\0\0\0\x88\0\0\x07\xaf\0\0\x0d\x6b\0\x02\xd0\x17\0\0\
\0\x90\0\0\x07\xaf\0\0\x0d\x98\0\x02\xd8\x3c\0\0\0\x98\0\0\x07\xaf\0\0\x0d\x98\
\0\x02\xd8\x42\0\0\0\xa0\0\0\x07\xaf\0\0\x0d\x98\0\x02\xd8\x0c\0\0\0\xc8\0\0\
\x07\xaf\0\0\x0a\x52\0\x02\xe0\x06\0\0\0\xd8\0\0\x07\xaf\0\0\x0c\xdd\0\x02\xec\
\x11\0\0\0\xe0\0\0\x07\xaf\0\0\x0d\x04\0\x02\xa0\x06\0\0\0\x10\0\0\x0e\x0c\0\0\
\0\x01\0\0\0\x88\0\0\0\x1e\0\0\x0d\xe2\0\0\0\0\0\0\x0e\x1d\0\0\0\x03\0\0\0\x18\
\0\0\0\x1e\0\0\x0d\xe2\0\0\0\0\0\0\0\x48\0\0\0\x1e\0\0\x0d\xe2\0\0\0\0\0\0\0\
\xb0\0\0\0\x1e\0\0\x0d\xe2\0\0\0\0\0\0\x0e\x30\0\0\0\x04\0\0\0\x38\0\0\0\x4e\0\
\0\x0d\xe6\0\0\0\0\0\0\0\xa0\0\0\0\x4e\0\0\x0d\xe6\0\0\0\0\0\0\0\xd8\0\0\0\x4e\
\0\0\x0d\xe6\0\0\0\0\0\0\x01\0\0\0\0\x4e\0\0\x0d\xe6\0\0\0\0\0\0\x0e\x42\0\0\0\
\x01\0\0\0\x38\0\0\0\x4e\0\0\x0d\xe6\0\0\0\0\0\0\x0e\x5b\0\0\0\x04\0\0\0\x78\0\
\0\0\x5c\0\0\x0d\xea\0\0\0\0\0\0\0\x80\0\0\0\x66\0\0\x0d\xef\0\0\0\0\0\0\0\x90\
\0\0\0\x5c\0\0\x0d\xea\0\0\0\0\0\0\0\x98\0\0\0\x66\0\0\x0d\xef\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x03\0\0\0\0\
\0\0\0\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\x02\x2c\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x09\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x02\x70\0\0\0\0\0\0\x02\xb8\0\0\0\x01\0\0\0\0\0\0\0\0\0\
\0\0\x08\0\0\0\0\0\0\0\x18\0\0\0\x11\0\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x05\x28\0\0\0\0\0\0\0\xb8\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\
\0\0\0\0\0\0\0\0\0\x22\0\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x05\xe0\0\0\0\0\0\0\x01\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\
\0\0\0\x35\0\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x06\xe8\0\0\
\0\0\0\0\x01\x58\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\x47\0\
\0\0\x01\0\0\0\0\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\x40\0\0\0\0\0\0\0\
\x90\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\x60\0\0\0\x01\0\0\
\0\0\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\xd0\0\0\0\0\0\0\0\xe8\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\x7b\0\0\0\x01\0\0\0\0\0\0\0\x03\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x09\xb8\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x83\0\0\0\x08\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x09\xbc\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\
\0\0\0\0\0\0\0\0\0\x88\0\0\0\x01\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x09\xbc\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\
\0\0\x8e\0\0\0\x01\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x09\xc8\0\0\0\
\0\0\0\0\x80\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\x01\xa0\0\0\
\0\x09\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0a\x48\0\0\0\0\0\0\0\x20\
\0\0\0\x02\0\0\0\x03\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\x01\xb5\0\0\0\x09\
\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0a\x68\0\0\0\0\0\0\0\x50\0\0\0\
\x02\0\0\0\x04\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\x01\xcc\0\0\0\x09\0\0\0\
\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0a\xb8\0\0\0\0\0\0\0\x70\0\0\0\x02\0\
\0\0\x05\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\x01\xe2\0\0\0\x09\0\0\0\0\0\0\
\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0b\x28\0\0\0\0\0\0\0\x20\0\0\0\x02\0\0\0\
\x06\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\x01\xff\0\0\0\x09\0\0\0\0\0\0\0\
\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0b\x48\0\0\0\0\0\0\0\x30\0\0\0\x02\0\0\0\x07\
\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\x02\x1e\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x0b\x78\0\0\0\0\0\0\x1e\x9a\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x08\0\0\0\0\0\0\0\0\0\0\x02\x23\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x2a\x18\0\0\0\0\0\0\x06\x6c\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\
\0\0\0\0\0\0";
}

#ifdef __cplusplus
struct local_storage *local_storage::open(const struct bpf_object_open_opts *opts) { return local_storage__open_opts(opts); }
struct local_storage *local_storage::open_and_load() { return local_storage__open_and_load(); }
int local_storage::load(struct local_storage *skel) { return local_storage__load(skel); }
int local_storage::attach(struct local_storage *skel) { return local_storage__attach(skel); }
void local_storage::detach(struct local_storage *skel) { local_storage__detach(skel); }
void local_storage::destroy(struct local_storage *skel) { local_storage__destroy(skel); }
const void *local_storage::elf_bytes(size_t *sz) { return local_storage__elf_bytes(sz); }
#endif /* __cplusplus */

__attribute__((unused)) static void
local_storage__assert(struct local_storage *s __attribute__((unused)))
{
#ifdef __cplusplus
#define _Static_assert static_assert
#endif
	_Static_assert(sizeof(s->bss->monitored_pid) == 4, "unexpected size of 'monitored_pid'");
	_Static_assert(sizeof(s->data->inode_storage_result) == 4, "unexpected size of 'inode_storage_result'");
	_Static_assert(sizeof(s->data->sk_storage_result) == 4, "unexpected size of 'sk_storage_result'");
#ifdef __cplusplus
#undef _Static_assert
#endif
}

#endif /* __LOCAL_STORAGE_SKEL_H__ */
